@@ -4,13 +4,17 @@ from amazon_web_services_helpers.aws_helper import AwsHelper
 
 class DynamoDbHelper:
     @staticmethod
-    def get_items(table_name, key, value):
+    def get_items(table_name, key, value, index_name=None):
         items = None
         ddb = AwsHelper().get_resource("dynamodb")
         table = ddb.Table(table_name)
         if key is not None and value is not None:
             filter = Key(key).eq(value)
-            query_result = table.query(KeyConditionExpression=filter)
+            query_result = None
+            if index_name:
+                query_result = table.query(IndexName=index_name, KeyConditionExpression=filter)
+            else:
+                query_result = table.query(KeyConditionExpression=filter)
             if query_result and "Items" in query_result:
                 items = query_result["Items"]
         return items
